Installation
============

TorchANI requires the latest preview version of PyTorch.

Please see `PyTorch's official site`_ for instructions of installing latest preview version of PyTorch.

Note that if you updated TorchANI, you may also need to update PyTorch.

After installing the correct PyTorch, you can install TorchANI by `pip` or `conda`:

.. code-block:: bash

    pip install torchani

or

.. code-block:: bash

    conda install -c conda-forge torchani

See https://github.com/conda-forge/torchani-feedstock for more information about the conda package.

.. _PyTorch's official site:
    https://pytorch.org/get-started/locally/
